=======
Credits
=======

`TextBlob`_ Development Lead
----------------------------

* Steven Loria <sloria1@gmail.com>

`textblob-de`_ Maintainer
-------------------------

* Markus Killer <m.killer@langui.ch>

Contributors
------------

None yet. Why not be the first?

.. _TextBlob: https://textblob.readthedocs.org/
.. _textblob-de: https://github.com/markuskiller/textblob-de


